#!/bin/bash

# Bolt environment variables
ADD_A_RECORD="${PT_add_a_record_bool}"
IP="${PT_ip_with_cidr}"
HOSTNAME="${PT_dns_hostname}"
TTL="${PT_dns_ttl}"

# Check if Docker installation is requested
if [ "$ADD_A_RECORD" != "true" ]; then
    echo '{"status": "skipped", "message": "A Record addition not requested, skipping..."}'
    exit 0
fi

# Check if required parameters are provided
if [ -z "$IP" ] || [ -z "$HOSTNAME" ] || [ -z "$TTL" ]; then
    echo '{"status": "failure", "message": "Error: Both ip_with_cidr, dns_hostname and ttl parameters must be provided"}'
    exit 1
fi

# Create DNS A record
IP_ADDRESS=$(echo ${IP} | cut -d'/' -f1)
nsupdate -k ../../keys/tsig.key << EOF
server ns1.moeny.ai
zone moeny.ai
update add ${HOSTNAME}.moeny.ai ${TTL} A ${IP_ADDRESS}
send
EOF

# Force zone file update on DNS server
ssh moeny@ns1.moeny.ai "sudo rndc sync moeny.ai"

echo '{"status": "success", "message": "A Record successfully added."}'